==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkGeoProjection.java <==
// java wrapper for vtkGeoProjection object
//

package vtk;
import vtk.*;

public class vtkGeoProjection extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetNumberOfProjections_2();
  public int GetNumberOfProjections()
    { return GetNumberOfProjections_2(); }

  private native String GetProjectionName_3(int id0);
  public String GetProjectionName(int id0)
    { return GetProjectionName_3(id0); }

  private native String GetProjectionDescription_4(int id0);
  public String GetProjectionDescription(int id0)
    { return GetProjectionDescription_4(id0); }

  private native void SetName_5(String id0);
  public void SetName(String id0)
    { SetName_5(id0); }

  private native String GetName_6();
  public String GetName()
    { return GetName_6(); }

  private native int GetIndex_7();
  public int GetIndex()
    { return GetIndex_7(); }

  private native String GetDescription_8();
  public String GetDescription()
    { return GetDescription_8(); }

  private native void SetCentralMeridian_9(double id0);
  public void SetCentralMeridian(double id0)
    { SetCentralMeridian_9(id0); }

  private native double GetCentralMeridian_10();
  public double GetCentralMeridian()
    { return GetCentralMeridian_10(); }

  private native void SetOptionalParameter_11(String id0,String id1);
  public void SetOptionalParameter(String id0,String id1)
    { SetOptionalParameter_11(id0,id1); }

  private native void RemoveOptionalParameter_12(String id0);
  public void RemoveOptionalParameter(String id0)
    { RemoveOptionalParameter_12(id0); }

  private native int GetNumberOfOptionalParameters_13();
  public int GetNumberOfOptionalParameters()
    { return GetNumberOfOptionalParameters_13(); }

  private native String GetOptionalParameterKey_14(int id0);
  public String GetOptionalParameterKey(int id0)
    { return GetOptionalParameterKey_14(id0); }

  private native String GetOptionalParameterValue_15(int id0);
  public String GetOptionalParameterValue(int id0)
    { return GetOptionalParameterValue_15(id0); }

  private native void ClearOptionalParameters_16();
  public void ClearOptionalParameters()
    { ClearOptionalParameters_16(); }

  public vtkGeoProjection() { super(); }

  public vtkGeoProjection(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-armv6h.pkg.tar.xz: vtk/vtkGeoProjection.java <==
// java wrapper for vtkGeoProjection object
//

package vtk;
import vtk.*;

public class vtkGeoProjection extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetNumberOfProjections_2();
  public int GetNumberOfProjections()
    { return GetNumberOfProjections_2(); }

  private native String GetProjectionName_3(int id0);
  public String GetProjectionName(int id0)
    { return GetProjectionName_3(id0); }

  private native String GetProjectionDescription_4(int id0);
  public String GetProjectionDescription(int id0)
    { return GetProjectionDescription_4(id0); }

  private native void SetName_5(String id0);
  public void SetName(String id0)
    { SetName_5(id0); }

  private native String GetName_6();
  public String GetName()
    { return GetName_6(); }

  private native int GetIndex_7();
  public int GetIndex()
    { return GetIndex_7(); }

  private native String GetDescription_8();
  public String GetDescription()
    { return GetDescription_8(); }

  private native void SetCentralMeridian_9(double id0);
  public void SetCentralMeridian(double id0)
    { SetCentralMeridian_9(id0); }

  private native double GetCentralMeridian_10();
  public double GetCentralMeridian()
    { return GetCentralMeridian_10(); }

  private native void SetOptionalParameter_11(String id0,String id1);
  public void SetOptionalParameter(String id0,String id1)
    { SetOptionalParameter_11(id0,id1); }

  private native void RemoveOptionalParameter_12(String id0);
  public void RemoveOptionalParameter(String id0)
    { RemoveOptionalParameter_12(id0); }

  private native int GetNumberOfOptionalParameters_13();
  public int GetNumberOfOptionalParameters()
    { return GetNumberOfOptionalParameters_13(); }

  private native String GetOptionalParameterKey_14(int id0);
  public String GetOptionalParameterKey(int id0)
    { return GetOptionalParameterKey_14(id0); }

  private native String GetOptionalParameterValue_15(int id0);
  public String GetOptionalParameterValue(int id0)
    { return GetOptionalParameterValue_15(id0); }

  private native void ClearOptionalParameters_16();
  public void ClearOptionalParameters()
    { ClearOptionalParameters_16(); }

  private native void SetPROJ4String_17(String id0);
  public void SetPROJ4String(String id0)
    { SetPROJ4String_17(id0); }

  private native String GetPROJ4String_18();
  public String GetPROJ4String()
    { return GetPROJ4String_18(); }

  public vtkGeoProjection() { super(); }

  public vtkGeoProjection(long id) { super(id); }
  public native long   VTKInit();

}
